==> xemacs-21.5.1.tar.gz: xemacs-21.5.1/lisp/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'menu '("menubar-items"))
(custom-add-loads 'printing '("printer"))
(custom-add-loads 'frames '("frame" "window-xemacs" "gui" "gnuserv"))
(custom-add-loads 'hypermedia '("wid-edit"))
(custom-add-loads 'programming '("cus-edit"))
(custom-add-loads 'widget-faces '("wid-edit"))
(custom-add-loads 'dired '("files"))
(custom-add-loads 'help '("help" "cus-edit" "hyper-apropos" "info"))
(custom-add-loads 'languages '("lisp-mode" "cus-edit" "font-lock"))
(custom-add-loads 'matching '("simple" "isearch-mode" "hyper-apropos"))
(custom-add-loads 'internal '("cus-edit"))
(custom-add-loads 'processes '("process" "gnuserv"))
(custom-add-loads 'font-lock '("font-lock"))
(custom-add-loads 'backup '("files"))
(custom-add-loads 'custom-buffer '("cus-edit"))
(custom-add-loads 'pui '("package-ui"))
(custom-add-loads 'fill-comments '("simple"))
(custom-add-loads 'build-report '("build-report"))
(custom-add-loads 'mail '("simple" "startup"))
(custom-add-loads 'development '("process" "lisp-mode" "cus-edit"))
(custom-add-loads 'log-message '("simple"))
(custom-add-loads 'auto-save '("files" "auto-save"))
(custom-add-loads 'help-appearance '("help" "help-macro"))
(custom-add-loads 'find-file '("files"))
(custom-add-loads 'package-tools '("package-get" "package-ui"))
(custom-add-loads 'widget-documentation '("wid-edit"))
(custom-add-loads 'build '("build-report"))
(custom-add-loads 'font-lock-faces '("font-lock"))
(custom-add-loads 'i18n '("cus-edit"))
(custom-add-loads 'custom-menu '("cus-edit"))
(custom-add-loads 'fill '("simple" "fill"))
(custom-add-loads 'display '("modeline" "toolbar" "scrollbar" "auto-show"))
(custom-add-loads 'terminals '("gnuserv"))
(custom-add-loads 'mouse '("mouse" "mwheel"))
(custom-add-loads 'dnd-debug '("dragdrop"))
(custom-add-loads 'applications '("cus-edit"))
(custom-add-loads 'emacs '("faces" "help" "files" "cus-edit" "package-get"))
(custom-add-loads 'data '("auto-save"))
(custom-add-loads 'comm '("ldap"))
(custom-add-loads 'package-get '("package-get"))
(custom-add-loads 'lisp '("lisp" "lisp-mode" "hyper-apropos"))
(custom-add-loads 'paren-blinking '("simple"))
(custom-add-loads 'gnuserv '("gnuserv"))
(custom-add-loads 'toolbar '("toolbar-items"))
(custom-add-loads 'modeline '("modeline"))
(custom-add-loads 'drag-n-drop '("dragdrop"))
(custom-add-loads 'customize '("wid-edit" "cus-edit"))
(custom-add-loads 'buffers-tab '("gutter-items"))
(custom-add-loads 'widget-browse '("wid-browse"))
(custom-add-loads 'custom-browse '("cus-edit"))
(custom-add-loads 'hyper-apropos '("hyper-apropos"))
(custom-add-loads 'custom-faces '("cus-edit"))
(custom-add-loads 'minibuffer '("simple" "minibuf"))
(custom-add-loads 'info '("toolbar-items" "info"))
(custom-add-loads 'wp '("printer" "cus-edit"))
(custom-add-loads 'vc '("files"))
(custom-add-loads 'keyboard '("cmdloop"))
(custom-add-loads 'docs '("hyper-apropos" "info"))
(custom-add-loads 'isearch '("isearch-mode"))
(custom-add-loads 'gutter '("gutter" "gutter-items"))
(custom-add-loads 'custom-magic-faces '("cus-edit"))
(custom-add-loads 'etags '("etags"))
(custom-add-loads 'info-faces '("info"))
(custom-add-loads 'widgets '("wid-browse" "wid-edit"))
(custom-add-loads 'auto-show '("auto-show"))
(custom-add-loads 'sound '("sound"))
(custom-add-loads 'editing '("simple" "abbrev" "fill" "mouse" "dragdrop" "cus-edit"))
(custom-add-loads 'abbrev '("abbrev" "files"))
(custom-add-loads 'files '("files"))
(custom-add-loads 'environment '("frame" "keydefs" "minibuf" "modeline" "window-xemacs" "menubar" "gutter" "toolbar-items" "cus-edit" "gnuserv" "sound" "x-init"))
(custom-add-loads 'buffers-menu '("menubar-items"))
(custom-add-loads 'external '("process" "cus-edit"))
(custom-add-loads 'killing '("simple"))
(custom-add-loads 'editing-basics '("cmdloop" "simple" "files" "lisp"))
(custom-add-loads 'ldap '("ldap"))
(custom-add-loads 'extensions '("auto-show" "wid-edit"))
(custom-add-loads 'faces '("faces" "cus-edit" "font-lock" "font" "hyper-apropos" "info" "wid-edit"))
(custom-add-loads 'font-menu '("font-menu"))
(custom-add-loads 'widget-button '("wid-edit"))
(custom-add-loads 'tools '("etags" "hyper-apropos"))
(custom-add-loads 'warnings '("simple"))
(custom-add-loads 'hyper-apropos-faces '("hyper-apropos"))
(custom-add-loads 'windows '("window" "window-xemacs"))
(custom-add-loads 'x '("gtk-faces" "x-faces"))

;;; custom-load.el ends here

==> xemacs-21.5.4.tar.gz: xemacs-21.5.4/lisp/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'menu '("menubar-items"))
(custom-add-loads 'printing '("printer"))
(custom-add-loads 'frames '("frame" "window-xemacs" "gui" "gnuserv"))
(custom-add-loads 'hypermedia '("wid-edit"))
(custom-add-loads 'programming '("cus-edit"))
(custom-add-loads 'widget-faces '("wid-edit"))
(custom-add-loads 'dired '("files"))
(custom-add-loads 'help '("help" "cus-edit" "hyper-apropos" "info"))
(custom-add-loads 'languages '("lisp-mode" "cus-edit" "font-lock"))
(custom-add-loads 'matching '("simple" "isearch-mode" "hyper-apropos"))
(custom-add-loads 'internal '("cus-edit"))
(custom-add-loads 'processes '("process" "gnuserv"))
(custom-add-loads 'font-lock '("font-lock"))
(custom-add-loads 'backup '("files"))
(custom-add-loads 'custom-buffer '("cus-edit"))
(custom-add-loads 'pui '("package-ui"))
(custom-add-loads 'fill-comments '("simple"))
(custom-add-loads 'build-report '("build-report"))
(custom-add-loads 'mail '("simple" "startup"))
(custom-add-loads 'development '("process" "lisp-mode" "cus-edit"))
(custom-add-loads 'log-message '("simple"))
(custom-add-loads 'auto-save '("files" "auto-save"))
(custom-add-loads 'help-appearance '("help" "help-macro"))
(custom-add-loads 'find-file '("files"))
(custom-add-loads 'package-tools '("package-get" "package-ui"))
(custom-add-loads 'widget-documentation '("wid-edit"))
(custom-add-loads 'build '("build-report"))
(custom-add-loads 'font-lock-faces '("font-lock"))
(custom-add-loads 'i18n '("cus-edit"))
(custom-add-loads 'custom-menu '("cus-edit"))
(custom-add-loads 'fill '("simple" "fill"))
(custom-add-loads 'display '("modeline" "toolbar" "scrollbar" "auto-show"))
(custom-add-loads 'terminals '("gnuserv"))
(custom-add-loads 'mouse '("mouse" "mwheel"))
(custom-add-loads 'dnd-debug '("dragdrop"))
(custom-add-loads 'applications '("cus-edit"))
(custom-add-loads 'emacs '("faces" "help" "files" "package-get" "cus-edit"))
(custom-add-loads 'data '("auto-save"))
(custom-add-loads 'comm '("ldap"))
(custom-add-loads 'package-get '("package-get"))
(custom-add-loads 'lisp '("lisp" "lisp-mode" "hyper-apropos"))
(custom-add-loads 'paren-blinking '("simple"))
(custom-add-loads 'find-function '("lib-complete"))
(custom-add-loads 'gnuserv '("gnuserv"))
(custom-add-loads 'toolbar '("toolbar-items"))
(custom-add-loads 'modeline '("modeline"))
(custom-add-loads 'drag-n-drop '("dragdrop"))
(custom-add-loads 'customize '("wid-edit" "cus-edit"))
(custom-add-loads 'buffers-tab '("gutter-items"))
(custom-add-loads 'widget-browse '("wid-browse"))
(custom-add-loads 'custom-browse '("cus-edit"))
(custom-add-loads 'hyper-apropos '("hyper-apropos"))
(custom-add-loads 'custom-faces '("cus-edit"))
(custom-add-loads 'minibuffer '("simple" "minibuf"))
(custom-add-loads 'info '("toolbar-items" "info"))
(custom-add-loads 'wp '("printer" "cus-edit"))
(custom-add-loads 'vc '("files"))
(custom-add-loads 'keyboard '("cmdloop"))
(custom-add-loads 'docs '("hyper-apropos" "info"))
(custom-add-loads 'isearch '("isearch-mode"))
(custom-add-loads 'gutter '("gutter" "gutter-items"))
(custom-add-loads 'custom-magic-faces '("cus-edit"))
(custom-add-loads 'etags '("etags"))
(custom-add-loads 'info-faces '("info"))
(custom-add-loads 'widgets '("wid-edit" "wid-browse"))
(custom-add-loads 'auto-show '("auto-show"))
(custom-add-loads 'sound '("sound"))
(custom-add-loads 'editing '("simple" "abbrev" "fill" "mouse" "cus-edit" "dragdrop"))
(custom-add-loads 'abbrev '("abbrev" "files"))
(custom-add-loads 'files '("files"))
(custom-add-loads 'environment '("frame" "keydefs" "minibuf" "modeline" "window-xemacs" "menubar" "gutter" "toolbar-items" "x-init" "cus-edit" "gnuserv" "sound"))
(custom-add-loads 'buffers-menu '("menubar-items"))
(custom-add-loads 'external '("process" "cus-edit"))
(custom-add-loads 'killing '("simple"))
(custom-add-loads 'editing-basics '("cmdloop" "simple" "files" "lisp"))
(custom-add-loads 'ldap '("ldap"))
(custom-add-loads 'extensions '("auto-show" "wid-edit"))
(custom-add-loads 'faces '("faces" "wid-edit" "font" "cus-edit" "font-lock" "hyper-apropos" "info"))
(custom-add-loads 'font-menu '("font-menu"))
(custom-add-loads 'widget-button '("wid-edit"))
(custom-add-loads 'tools '("etags" "hyper-apropos"))
(custom-add-loads 'warnings '("simple"))
(custom-add-loads 'hyper-apropos-faces '("hyper-apropos"))
(custom-add-loads 'windows '("window" "window-xemacs"))
(custom-add-loads 'x '("x-faces" "gtk-faces"))

;;; custom-load.el ends here
